%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% File:     isset.cls           (LaTeX Document class option "isset")
%
% Authors: Teresa Makuch      (tesiamakuch@gmail.com)
%          AGH University of Science and Technology, Kraków, POLAND
%
% Based on aghdpl.cls by  Marcin Szpyrka     (mszpyrka@agh.edu.pl)
%                         Grzegorz J. Nalepa (gjn@agh.edu.pl)
%                         Paweł Kłeczek      (p.l.kleczek@gmail.com)
% and oska.cls by   Teresa Makuch      (tesiamakuch@gmail.com)
%                   Szymon Mikulicz    (szymon.mikulicz@posteo.net)
%                   Marcel Piszak      (marcel.piszak@wp.pl)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\message{*** [isset.cls] ---  (TM)  v1.0.0 <07.04.2021>  ***}

\newif\ifpdflatex\pdflatexfalse
\NeedsTeXFormat{LaTeX2e} %
\ProvidesClass{isset}

\RequirePackage{etoolbox}
\def\email#1    {\gdef\@email{#1}}
\newbool{@langPL}
\setbool{@langPL}{false}
\DeclareOption{pdflatex}{\pdflatextrue}
\DeclareOption{polski}{\setbool{@langPL}{true}}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions\relax
\LoadClass[a4paper,oneside]{article}

\RequirePackage{newtxtext}
\RequirePackage{anyfontsize}
\RequirePackage[T1]{fontenc}
\RequirePackage[utf8]{inputenc}
\RequirePackage{graphicx}
\RequirePackage{geometry}
\RequirePackage{fancyhdr}
\RequirePackage{titling}
\RequirePackage{titlesec}
% \RequirePackage{tocloft}
% \RequirePackage{mfirstuc}
\RequirePackage{setspace}
\RequirePackage[
    breaklinks=true,
    colorlinks=true,
    linkcolor=red,
    urlcolor=blue,
    citecolor=red
    ]{hyperref}

\RequirePackage[font=small, labelfont=bf, labelsep=quad]{caption}
\RequirePackage{subcaption}
\RequirePackage[detect-weight=true, detect-family=true]{siunitx}
\RequirePackage{enumerate}
\RequirePackage{enumitem}
\RequirePackage{mathtools}
\RequirePackage{amssymb}

\RequirePackage[all,defaultlines=2]{nowidow}
\RequirePackage{csquotes}
\RequirePackage[
    style=numeric,
    sorting=none,
    language=autobib,
    autolang=other,
    backref=false,
    isbn=true,
    url=false,
    maxbibnames=6,
    minbibnames=6
    ]{biblatex}

\geometry{lmargin=30mm, rmargin=30mm, tmargin=35mm, bmargin=35mm, foot=12.5mm, head=0mm}
\setlength{\parindent}{\leftmargin}
\RequirePackage{indentfirst}
\frenchspacing
\sloppy
\flushbottom
% \onehalfspacing
\brokenpenalty=10000\relax

\RequirePackage[noblocks]{authblk}
\renewcommand\Affilfont{\small}

\date{}
\pretitle{\begin{center}\Large\bfseries\MakeUppercase}
\posttitle{\end{center}\normalsize}
\predate{\begin{center}\small\itshape\@email}
\postdate{\end{center}}

\ifbool{@langPL}{%
        \RequirePackage{polski}
        \RequirePackage[polish]{babel}
        \sisetup{
          output-decimal-marker = {,},
          group-separator={~}
        }
        \DeclareQuoteAlias{croatian}{polish}
        \usepackage{icomma}

        \AtBeginDocument{
        	\renewcommand{\tablename}{Tabela}
        	\renewcommand{\figurename}{Rysunek}
        }
        \renewcommand\Authand{i}
        \renewcommand\Authands{~i~}
    }{
        \RequirePackage[english]{babel}
    }

\AtBeginBibliography{
\renewcommand\labelnamepunct{:\space}
\renewcommand\newunitpunct{\addcomma\space}
\renewcommand{\finentrypunct}{}

\renewcommand{\bibopenparen}{\addcomma\addspace}
\renewcommand{\bibcloseparen}{\addspace}
}

\captionsetup{justification=centering}

\renewcommand\UrlFont{\rmfamily\itshape}

\titleformat{\section}[block]
{\bfseries\scshape\large}{\filright \thesection. }{0ex}{}
\titleformat{\subsection}[block]
{\bfseries\scshape\normalsize}{\filright \thesubsection. }{0ex}{}
\titleformat{\subsubsection}[block]
{\scshape\normalsize}{\filright \normalsize\thesubsubsection. }{0ex}{}
